// SPDX-License-Identifier: MPL-2.0

//! [`Combobox`].

use crate::prelude::*;

def_subcontrol!(
    docs: "


        # Examples

        ```no_run
        // TODO
        ```
    ",
    ty: Combobox,
    handle: uiCombobox,
);

impl Combobox {}
